@@ -67,7 +67,8 @@ class MobileCommand(object):
     UPDATE_SETTINGS = 'updateSettings'
     SET_LOCATION = 'setLocation'
     GET_LOCATION = 'getLocation'
-    GET_DEVICE_TIME = 'getDeviceTime'
+    GET_DEVICE_TIME_GET = 'getDeviceTimeGet'
+    GET_DEVICE_TIME_POST = 'getDeviceTimePost'
     CLEAR = 'clear'
     START_RECORDING_SCREEN = 'startRecordingScreen'
     STOP_RECORDING_SCREEN = 'stopRecordingScreen'
